@@ -1,9 +1,9 @@
-use crate::{Hypergraph, SharedTrait};
+use crate::{HyperedgeTrait, Hypergraph, VertexTrait};
 
 impl<V, HE> Hypergraph<V, HE>
 where
-    V: SharedTrait,
-    HE: SharedTrait,
+    V: VertexTrait,
+    HE: HyperedgeTrait,
 {
     /// Returns the number of hyperedges in the hypergraph.
     pub fn count_hyperedges(&self) -> usize {
