@@ -1,3 +1,5 @@
+use rayon::prelude::*;
+
 use crate::{errors::HypergraphError, HyperedgeTrait, Hypergraph, VertexIndex, VertexTrait};
 
 impl<V, HE> Hypergraph<V, HE>
@@ -12,7 +14,7 @@ where
     ) -> Result<Vec<usize>, HypergraphError<V, HE>> {
         vertices
             .as_ref()
-            .iter()
+            .par_iter()
             .map(|vertex_index| self.get_internal_vertex(*vertex_index))
             .collect()
     }
