@@ -1,11 +1,12 @@
 use crate::{
-    core::shared::Connection, errors::HypergraphError, Hypergraph, SharedTrait, VertexIndex,
+    core::shared::Connection, errors::HypergraphError, HyperedgeTrait, Hypergraph, VertexIndex,
+    VertexTrait,
 };
 
 impl<V, HE> Hypergraph<V, HE>
 where
-    V: SharedTrait,
-    HE: SharedTrait,
+    V: VertexTrait,
+    HE: HyperedgeTrait,
 {
     /// Gets the out-degree of a vertex.
     /// <https://en.wikipedia.org/wiki/Directed_graph#Indegree_and_outdegree>
